@@ -670,7 +670,10 @@ public:
       evlrs = (LASevlr*)malloc(sizeof(LASevlr)*number_of_extended_variable_length_records);
     }
     evlrs[i].reserved = 0; // used to be 0xAABB
-    strncpy(evlrs[i].user_id, user_id, 16);
+    // Fix #61
+    int len = 0 ; while(*(user_id+len) != '\0' && len < 16) len++;
+    memcpy(evlrs[i].user_id, user_id, len);
+    //strncpy(evlrs[i].user_id, user_id, 16);
     evlrs[i].record_id = record_id;
     evlrs[i].record_length_after_header = record_length_after_header;
     if (keep_description && found_description)
