@@ -282,19 +282,20 @@ BOOL LASreaderTXT::open(FILE* file, const CHAR* file_name, U8 point_type, const
     {
       if (fgets(line, 512, file))
       {
-#ifdef _WIN32
-        if (sscanf(line, "%I64d", &npoints) != 1)
+// temporarily comment this portion that is not useful in rlas. See #62
+/*#ifdef _WIN32
+        if (sscanf(line, "%" PRId64 "", &npoints) != 1)
 #else
-        if (sscanf(line, "%lld", &npoints) != 1)
-#endif
+        if (sscanf(line, "%" PRId64 "", &npoints) != 1)
+#endif*/
         {
           REprintf( "ERROR: parsing number of points for '-itps'\n");
           return FALSE;
         }
 #ifdef _WIN32
-        REprintf( "PTS header states %I64d points. ignoring ...\n", npoints);
+        REprintf( "PTS header states %" PRId64 " points. ignoring ...\n", npoints);
 #else
-        REprintf( "PTS header states %lld points. ignoring ...\n", npoints);
+        REprintf( "PTS header states %" PRId64 " points. ignoring ...\n", npoints);
 #endif
         npoints = 0;
       }
@@ -336,9 +337,9 @@ BOOL LASreaderTXT::open(FILE* file, const CHAR* file_name, U8 point_type, const
       }
       npoints = (I64)ncols*(I64)nrows;
 #ifdef _WIN32
-      REprintf( "PTX header states %d cols by %d rows aka %I64d points. ignoring ...\n", ncols, nrows, npoints);
+      REprintf( "PTX header states %d cols by %d rows aka %" PRId64 " points. ignoring ...\n", ncols, nrows, npoints);
 #else
-      REprintf( "PTX header states %d cols by %d rows aka %lld points. ignoring ...\n", ncols, nrows, npoints);
+      REprintf( "PTX header states %d cols by %d rows aka %" PRId64 " points. ignoring ...\n", ncols, nrows, npoints);
 #endif
       F64 translation[3];
       if (fgets(line, 512, file))
@@ -554,9 +555,9 @@ BOOL LASreaderTXT::open(FILE* file, const CHAR* file_name, U8 point_type, const
     }
 
 #ifdef _WIN32
-    REprintf( "counted %I64d points in populate pass.\n", npoints);
+    REprintf( "counted %" PRId64 " points in populate pass.\n", npoints);
 #else
-    REprintf( "counted %lld points in populate pass.\n", npoints);
+    REprintf( "counted %" PRId64 " points in populate pass.\n", npoints);
 #endif
 
     if (point.extended_point_type || (npoints > U32_MAX) || header.extended_number_of_points_by_return[5] || header.extended_number_of_points_by_return[6] || header.extended_number_of_points_by_return[7] || header.extended_number_of_points_by_return[8] || header.extended_number_of_points_by_return[9] || header.extended_number_of_points_by_return[10] || header.extended_number_of_points_by_return[11] || header.extended_number_of_points_by_return[12] || header.extended_number_of_points_by_return[13] || header.extended_number_of_points_by_return[14])
@@ -648,11 +649,12 @@ BOOL LASreaderTXT::open(FILE* file, const CHAR* file_name, U8 point_type, const
     {
       if (!populated_header)
       {
-#ifdef _WIN32
-        if (sscanf(line, "%I64d", &npoints) != 1)
+// temporarily comment this portion that is not useful in rlas. See #62
+/*#ifdef _WIN32
+        if (sscanf(line, "%" PRId64 "", &npoints) != 1)
 #else
-        if (sscanf(line, "%lld", &npoints) != 1)
-#endif
+        if (sscanf(line, "%" PRId64 "", &npoints) != 1)
+#endif*/
         {
           REprintf( "ERROR: parsing number of points for '-itps'\n");
           return FALSE;
@@ -1158,9 +1160,9 @@ BOOL LASreaderTXT::read_point_default()
           if (p_count != npoints)
           {
 #ifdef _WIN32
-            REprintf("WARNING: end-of-file after %I64d of %I64d points\n", p_count, npoints);
+            REprintf("WARNING: end-of-file after %" PRId64 " of %" PRId64 " points\n", p_count, npoints);
 #else
-            REprintf("WARNING: end-of-file after %lld of %lld points\n", p_count, npoints);
+            REprintf("WARNING: end-of-file after %" PRId64 " of %" PRId64 " points\n", p_count, npoints);
 #endif
           }
         }
@@ -1171,9 +1173,9 @@ BOOL LASreaderTXT::read_point_default()
             if (p_count != npoints)
             {
 #ifdef _WIN32
-              REprintf("WARNING: end-of-file after %I64d of %I64d points\n", p_count, npoints);
+              REprintf("WARNING: end-of-file after %" PRId64 " of %" PRId64 " points\n", p_count, npoints);
 #else
-              REprintf("WARNING: end-of-file after %lld of %lld points\n", p_count, npoints);
+              REprintf("WARNING: end-of-file after %" PRId64 " of %" PRId64 " points\n", p_count, npoints);
 #endif
             }
           }
